==> haskell-binary-orphans-1.0.4.1-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-orphans
version:              1.0.4.1
visibility:           public
id:                   binary-orphans-1.0.4.1-FU6aCi1V9JbAp0Gcm8bVLd
key:                  binary-orphans-1.0.4.1-FU6aCi1V9JbAp0Gcm8bVLd
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  a33e02dfac12800df017b9a885608e68
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-9.2.8/site-local/binary-orphans-1.0.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/binary-orphans-1.0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-orphans
hs-libraries:         HSbinary-orphans-1.0.4.1-FU6aCi1V9JbAp0Gcm8bVLd
depends:
    base-4.16.4.0 binary-0.8.9.0
    data-array-byte-0.1.0.1-71m0qUbz0GPK2XPFn43oUy transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-orphans-1.0.4.1-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-orphans
version:              1.0.4.1
visibility:           public
id:                   binary-orphans-1.0.4.1-ALnGsgsBSaS89y7xGEnEWZ
key:                  binary-orphans-1.0.4.1-ALnGsgsBSaS89y7xGEnEWZ
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  48dd0a833c51a75f6c979be1402e4a0d
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-9.2.8/site-local/binary-orphans-1.0.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/binary-orphans-1.0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-orphans
hs-libraries:         HSbinary-orphans-1.0.4.1-ALnGsgsBSaS89y7xGEnEWZ
depends:
    base-4.16.4.0 binary-0.8.9.0
    data-array-byte-0.1.0.1-71m0qUbz0GPK2XPFn43oUy transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
